utils::globalVariables(c("x.sorted", "m", "subgroup", "Sensitivity",
                         "Specificity", "value", "metric", "Precision",
                         "Recall", "optimal_cutpoint", "ymin", "ymax",
                         "m_unsmoothed", "direction", "method", "AUC",
                         "boot", "TP_b", "roc_curve_oob"))